package lab5;

import c4e.phidget.HardwareInterface;

import java.util.Scanner;

import com.phidgets.AdvancedServoPhidget;

public class MotionCalibration extends HardwareInterface
{

	// ------------------------------------Attributes
	private static final double SERVO_0_POSITION = 115;
	private static final double SERVO_1_POSITION = 115;
	
	private Scanner input;
	private double translationSpeed;
	private double rotationSpeed;
	private long timerDelay;

	// ------------------------------------Constructor
	public MotionCalibration(boolean debug)
	{
		super(debug);
		this.input = new Scanner(System.in);
		this.translationSpeed = 0;
		this.rotationSpeed = 0;
		this.timerDelay = 1000;
		this.setTimer(this.timerDelay);
	}

	// ------------------------------------Timer
	@Override
	public void timerCallback()
	{
		AdvancedServoPhidget servo = this.getServoBoard();
		if (servo == null)
		{
			System.out.println("Waiting for servo to wake up ...");
			this.setTimer(this.timerDelay);
			return;
		}

		this.setServoPosition(0, SERVO_0_POSITION);
		this.setServoPosition(1, SERVO_1_POSITION);
		this.setServoEngageState(0, true);
		this.setServoEngageState(1, true);

		//-------------------------------------------------------------------------Translation:
		System.out.println("Calibrating linear motion (forward 20 cm/sec)");
		double nextSpeed = this.translationSpeed;
		while (nextSpeed > -1000)
		{
			this.translationSpeed = nextSpeed;
			System.out.println("Robot will move for 5 seconds at speed: " + this.translationSpeed);
			this.setServoPosition(0, SERVO_0_POSITION + this.translationSpeed);
			this.setServoPosition(1, SERVO_1_POSITION - this.translationSpeed);
			c4e.util.ToolBox.sleep(5 * 1000);
			this.setServoPosition(0, SERVO_0_POSITION);
			this.setServoPosition(1, SERVO_1_POSITION);
			System.out.print("Enter a new translational speed (or -1000 to end) ... ");
			nextSpeed = input.nextDouble();
		}

		//-------------------------------------------------------------------------Rotation:
		System.out.println("Calibrating rotation motion (counterclockwise)");
		nextSpeed = this.rotationSpeed;
		while (nextSpeed > -1000)
		{
			rotationSpeed = nextSpeed;
			System.out.println("Robot will rotate for 5 seconds at speed: " + this.rotationSpeed);
			this.setServoPosition(0, SERVO_0_POSITION + this.rotationSpeed);
			this.setServoPosition(1, SERVO_1_POSITION + this.rotationSpeed);
			c4e.util.ToolBox.sleep(5 * 1000);
			this.setServoPosition(0, SERVO_0_POSITION);
			this.setServoPosition(1, SERVO_1_POSITION);
			System.out.print("Enter a new rotational speed (or -1000 to end) ... ");
			nextSpeed = input.nextDouble();
		}

		this.setServoEngageState(0, false);
		this.setServoEngageState(1, false);

		//-------------------------------------------------------------------------Done:
		System.out.println("Translational speed is " + this.translationSpeed);
		System.out.println("Rotational speed is " + this.rotationSpeed);
		System.exit(0);
	}
}